@@ -18,7 +18,8 @@ use Carp;
 # package variables
 ########################################################################
 
-our $VERSION    = v1.30.0;
+our $VERSION    = '1.41';
+$VERSION        = eval $VERSION;
 
 # minimal sanity check for valid class name, used in both
 # O::T and O::T::U.
@@ -97,12 +98,28 @@ AUTOLOAD
     # this version does slightly more work since it 
     # has to put using the module into the caller's
     # class before calling the constructor.
+    #
+    # the eval is unavoidable since use requires the 
+    # module's package name as a bareword.
 
     my ( undef, $proto, @argz ) = @_;
 
     $proto
     or croak "Object::Trampoline::Use: false prototype.";
 
+    # sanity check: the prototype is words glued together with 
+    # double-colons. not perfect but worthwhile since most 
+    # injection attempts will at least require a path or space.
+
+    for( split '::' => $proto )
+    {
+        /\W/ and croak
+        "Botched trampoline_use: '$_' invalid module name";
+    }
+
+    # Note: add a sanity pre-check w/ warning for non-existant
+    # module.
+
     my $method  = ( split /::/, $AUTOLOAD )[ -1 ];
     my $caller  = caller;
 
@@ -265,6 +282,43 @@ simplifies runtime definition of handler classes.
     # Note: isa and can are overloaded. Calling $lazy->isa will
     # convert the object and return the corret type.
 
+    # you use a module that does not check for forks and will
+    # fail if the object is created prior to forking. adding
+    # a sanity check in the constructor will delay the check
+    # until the object is used. using O::T::B delays the check
+    # but still makes the object available (e.g., for export
+    # to other modules).
+
+    packge WhatEver;
+
+    my $parent  = $$;
+
+    sub new
+    {
+        my $obj = &construct;
+
+        $object->initialize( @_ );
+
+        $object
+    }
+
+    sub initialize
+    {
+        $$ != $parent
+        or die "Creating WhatEver in parent process";
+        
+        # safe to create the object
+
+        my ( $obj, @argz ) = @_;
+
+        ...
+    }
+
+    ...
+
+    my $post_fork_object
+    = bless sub { WhatEver->new( ... ) }, 'Object::Trampoline::Bounce';
+
 =head1 DESCRIPTION
 
 There are times when constructing an object is expensive
